@ECHO OFF
COLOR 17

:: Display output so that user knows what is going on.
ECHO.
ECHO Checking for Administrator rights.
ECHO This may take a moment.

:: Check if we have admin rights.
FSUTIL DIRTY QUERY %SystemDrive%>NUL
IF %ERRORLEVEL% NEQ 0 (GOTO PromptForAdmin) ELSE (GOTO ContinueProcessing)

:PromptForAdmin
:: Launch CMD with Administrator rights using PowerShell, making sure CMD exits when done.
POWERSHELL.EXE -Command Start-Process '%~f0' -Verb RunAs && EXIT

:ContinueProcessing
CLS

:: Continue with rest of batch file.

::Display main menu, and set MenuChoice to "0" in case there is no input.
:MainMenu
CLS
SET MenuChoice=0
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO _______________________________________________________________________________
ECHO                                       ^|
ECHO  1 - Enable general debug logs.       ^|  2 - Disable general debug logs.
ECHO                                       ^|
ECHO  3 - Enable Scan Engine logs.         ^|  4 - Disable Scan Engine logs.
ECHO                                       ^|
ECHO  5 - Enable Cleaning Engine logs.     ^|  6 - Disable Cleaning Engine logs.
ECHO                                       ^|

::Only show x86 section on 64-bit editions of Windows.
IF DEFINED ProgramW6432 (
	ECHO  7 - Enable x86 general debug logs.   ^|  8 - Disable x86 general debug logs.
	ECHO                                       ^|
	ECHO  9 - Enable x86 Scan Engine logs.     ^| 10 - Disable x86 Scan Engine logs.
	ECHO                                       ^|
	ECHO 11 - Enable x86 Cleaning Engine logs. ^| 12 - Disable x86 Cleaning Engine logs.
	ECHO                                       ^|
)

::Finish displaying rest of menu, and prompt for user input.
ECHO  0 - Exit.                            ^|
ECHO _______________________________________________________________________________
ECHO.
SET /P MenuChoice=Enter a number from the menu above, then press ^"Enter^"^> 

::Analyze input, and jump to the appropriate section.
IF %MenuChoice%==1 GOTO DebugLoggingOn
IF %MenuChoice%==2 GOTO DebugLoggingOff
IF %MenuChoice%==3 GOTO ScanEngineLoggingOn
IF %MenuChoice%==4 GOTO ScanEngineLoggingOff
IF %MenuChoice%==5 GOTO CleaningEngineLoggingOn
IF %MenuChoice%==6 GOTO CleaningEngineLoggingOff
IF %MenuChoice%==7 GOTO x86DebugLoggingOn
IF %MenuChoice%==8 GOTO x86DebugLoggingOff
IF %MenuChoice%==9 GOTO x86ScanEngineLoggingOn
IF %MenuChoice%==10 GOTO x86ScanEngineLoggingOff
IF %MenuChoice%==11 GOTO x86CleaningEngineLoggingOn
IF %MenuChoice%==12 GOTO x86CleaningEngineLoggingOff
IF %MenuChoice%==0 GOTO EOF

::If none of the conditional statements return "true", then go back to the main menu to allow user to try again.
GOTO MainMenu

::Create registry entry for general debug logs.
:DebugLoggingOn
CLS
ECHO.
REG ADD "HKLM\SOFTWARE\Emsi Software GmbH" /v GenerateDebugOutput /f /t REG_DWORD /d 1
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO General debug logging has been turned on.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Delete registry entry for general debug logs.
:DebugLoggingOff
CLS
ECHO.
REG DELETE "HKLM\SOFTWARE\Emsi Software GmbH" /v GenerateDebugOutput /f
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO General debug logging has been turned off.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Create registry entry for Scan Engine debug logs.
:ScanEngineLoggingOn
CLS
ECHO.
REG ADD "HKEY_LOCAL_MACHINE\SOFTWARE\Emsisoft" /v EngineDebugOutput /f /t REG_DWORD /d 1
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO Scan Engine debug logging has been turned on.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Delete registry entry for Scan Engine debug logs.
:ScanEngineLoggingOff
CLS
ECHO.
REG DELETE "HKEY_LOCAL_MACHINE\SOFTWARE\Emsisoft" /v EngineDebugOutput /f
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO Scan Engine debug logging has been turned off.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Create registry entry for Cleaning Engine debug logs.
:CleaningEngineLoggingOn
CLS
ECHO.
REG ADD "HKEY_LOCAL_MACHINE\SOFTWARE\Emsisoft GmbH" /v CleaningDebugOutput /f /t REG_DWORD /d 7
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO Cleaning Engine debug logging has been turned on.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Delete registry entry for Cleaning Engine debug logs.
:CleaningEngineLoggingOff
CLS
ECHO.
REG DELETE "HKEY_LOCAL_MACHINE\SOFTWARE\Emsisoft GmbH" /v CleaningDebugOutput /f
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO Cleaning Engine debug logging has been turned off.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Create x86 registry entry for general debug logs.
:x86DebugLoggingOn
CLS
ECHO.
REG ADD "HKLM\SOFTWARE\Wow6432Node\Emsi Software GmbH" /v GenerateDebugOutput /f /t REG_DWORD /d 1
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO x86 general debug logging has been turned on.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Delete x86 registry entry for general debug logs.
:x86DebugLoggingOff
CLS
ECHO.
REG DELETE "HKLM\SOFTWARE\Wow6432Node\Emsi Software GmbH" /v GenerateDebugOutput /f
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO x86 general debug logging has been turned off.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Create x86 registry entry for Scan Engine debug logs.
:x86ScanEngineLoggingOn
CLS
ECHO.
REG ADD "HKEY_LOCAL_MACHINE\SOFTWARE\Wow6432Node\Emsisoft" /v EngineDebugOutput /f /t REG_DWORD /d 1
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO x86 Scan Engine debug logging has been turned on.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Delete x86 registry entry for Scan Engine debug logs.
:x86ScanEngineLoggingOff
CLS
ECHO.
REG DELETE "HKEY_LOCAL_MACHINE\SOFTWARE\Wow6432Node\Emsisoft" /v EngineDebugOutput /f
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO x86 Scan Engine debug logging has been turned off.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Create x86 registry entry for Cleaning Engine debug logs.
:x86CleaningEngineLoggingOn
CLS
ECHO.
REG ADD "HKEY_LOCAL_MACHINE\SOFTWARE\Wow6432Node\Emsisoft GmbH" /v CleaningDebugOutput /f /t REG_DWORD /d 7
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO x86 Cleaning Engine debug logging has been turned on.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::Delete x86 registry entry for Cleaning Engine debug logs.
:x86CleaningEngineLoggingOff
CLS
ECHO.
REG DELETE "HKEY_LOCAL_MACHINE\SOFTWARE\Wow6432Node\Emsisoft GmbH" /v CleaningDebugOutput /f
CLS
ECHO.
ECHO ============================
ECHO = Emsisoft Debug Tool v1.1 =
ECHO ============================
ECHO.
ECHO x86 Cleaning Engine debug logging has been turned off.
ECHO.
ECHO Please note that if you have Emsisoft Anti-Malware or Emsisoft Internet
ECHO Security installed, that your computer will need to be restarted for the
ECHO changes to take effect.
ECHO.
PAUSE
GOTO MainMenu

::End of file, used to exit from main menu.
:EOF